==> sqlx-core-0.1.2.crate: sqlx-core-0.1.2/src/describe.rs <==
//! Types for returning SQL type information about queries.

use crate::types::HasTypeMetadata;
use crate::Database;
use std::fmt::{self, Debug};

/// The return type of [Executor::describe].
#[non_exhaustive]
pub struct Describe<DB>
where
    DB: Database + ?Sized,
{
    /// The expected types for the parameters of the query.
    pub param_types: Box<[<DB as HasTypeMetadata>::TypeId]>,

    /// The type and table information, if any for the results of the query.
    pub result_columns: Box<[Column<DB>]>,
}

impl<DB> Debug for Describe<DB>
where
    DB: Database,
    <DB as HasTypeMetadata>::TypeId: Debug,
    Column<DB>: Debug,
{
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        f.debug_struct("Describe")
            .field("param_types", &self.param_types)
            .field("result_columns", &self.result_columns)
            .finish()
    }
}

/// A single column of a result set.
#[non_exhaustive]
pub struct Column<DB>
where
    DB: Database + ?Sized,
{
    pub name: Option<Box<str>>,
    pub table_id: Option<<DB as HasTypeMetadata>::TableId>,
    pub type_id: <DB as HasTypeMetadata>::TypeId,
}

impl<DB> Debug for Column<DB>
where
    DB: Database + ?Sized,
    <DB as HasTypeMetadata>::TableId: Debug,
    <DB as HasTypeMetadata>::TypeId: Debug,
{
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        f.debug_struct("Column")
            .field("name", &self.name)
            .field("table_id", &self.table_id)
            .field("type_id", &self.type_id)
            .finish()
    }
}

==> sqlx-core-0.3.2.crate: sqlx-core-0.3.2/src/describe.rs <==
//! Types for returning SQL type information about queries.

use std::fmt::{self, Debug};

use crate::database::Database;

/// The return type of [`Executor::describe`].
///
/// [`Executor::describe`]: crate::executor::Executor::describe
#[non_exhaustive]
pub struct Describe<DB>
where
    DB: Database + ?Sized,
{
    /// The expected types for the parameters of the query.
    pub param_types: Box<[Option<DB::TypeInfo>]>,

    /// The type and table information, if any for the results of the query.
    pub result_columns: Box<[Column<DB>]>,
}

impl<DB> Debug for Describe<DB>
where
    DB: Database,
    DB::TypeInfo: Debug,
    Column<DB>: Debug,
{
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        f.debug_struct("Describe")
            .field("param_types", &self.param_types)
            .field("result_columns", &self.result_columns)
            .finish()
    }
}

/// A single column of a result set.
#[non_exhaustive]
pub struct Column<DB>
where
    DB: Database + ?Sized,
{
    pub name: Option<Box<str>>,
    pub table_id: Option<DB::TableId>,
    pub type_info: Option<DB::TypeInfo>,
    /// Whether or not the column cannot be `NULL` (or if that is even knowable).
    pub non_null: Option<bool>,
}

impl<DB> Debug for Column<DB>
where
    DB: Database + ?Sized,
    DB::TableId: Debug,
    DB::TypeInfo: Debug,
{
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        f.debug_struct("Column")
            .field("name", &self.name)
            .field("table_id", &self.table_id)
            .field("type_info", &self.type_info)
            .field("non_null", &self.non_null)
            .finish()
    }
}
